==> jc-1.4.0.tar.gz: java/security/SignedObject.h <==
// public final class java.security.SignedObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1d6c09729ddd8b58 java_security_SignedObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_SignedObject_H_
#define _JC_java_security_SignedObject_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_io_Serializable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_Signature$object;

// Typedefs
typedef struct _jc_java_security_SignedObject$sub_refs	_jc_java_security_SignedObject$sub_refs;
typedef struct _jc_java_security_SignedObject$sub_nonrefs	_jc_java_security_SignedObject$sub_nonrefs;
typedef struct _jc_java_security_SignedObject$refs	_jc_java_security_SignedObject$refs;
typedef struct _jc_java_security_SignedObject$nonrefs	_jc_java_security_SignedObject$nonrefs;
typedef struct _jc_java_security_SignedObject$object	_jc_java_security_SignedObject$object;

typedef struct _jc_java_security_SignedObject$fields_struct	_jc_java_security_SignedObject$fields_struct;
typedef const struct _jc_java_security_SignedObject$vmethods	_jc_java_security_SignedObject$vmethods;
typedef const struct _jc_java_security_SignedObject$vtable	_jc_java_security_SignedObject$vtable;
typedef const struct _jc_java_security_SignedObject$vtype	_jc_java_security_SignedObject$vtype;

// Class fields structure
struct _jc_java_security_SignedObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_SignedObject$fields_struct _jc_java_security_SignedObject$class_fields;

// Constructors
extern void _jc_java_security_SignedObject$method$_init$21c93dd2028dcec7(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_security_Signature$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_security_SignedObject$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_java_security_SignedObject$object *);
extern struct _jc_java_lang_Object$object *_jc_java_security_SignedObject$method$getObject$3a2eec332ceac060(_jc_env *, struct _jc_java_security_SignedObject$object *);
extern _jc_byte_array *_jc_java_security_SignedObject$method$getSignature$40b505c8be88925d(_jc_env *, struct _jc_java_security_SignedObject$object *);
extern void _jc_java_security_SignedObject$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_java_io_ObjectInputStream$object *);
extern jboolean _jc_java_security_SignedObject$method$verify$36c10db3883f887f(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_object *, struct _jc_java_security_Signature$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_SignedObject$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_java_security_SignedObject$method_info$getObject$3a2eec332ceac060;
extern _jc_method _jc_java_security_SignedObject$method_info$getSignature$40b505c8be88925d;
extern _jc_method _jc_java_security_SignedObject$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_java_security_SignedObject$method_info$verify$36c10db3883f887f;

// Virtual methods structure
struct _jc_java_security_SignedObject$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_java_security_SignedObject$object *);
	struct _jc_java_lang_Object$object	*(*getObject$3a2eec332ceac060)(_jc_env *, struct _jc_java_security_SignedObject$object *);
	_jc_byte_array	*(*getSignature$40b505c8be88925d)(_jc_env *, struct _jc_java_security_SignedObject$object *);
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_java_io_ObjectInputStream$object *);
	jboolean	(*verify$36c10db3883f887f)(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_object *, struct _jc_java_security_Signature$object *);
};

// Vtable
struct _jc_java_security_SignedObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_SignedObject$vmethods	java_security_SignedObject;
};

// Vtype
struct _jc_java_security_SignedObject$vtype {
	_jc_type			type;
	_jc_java_security_SignedObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_SignedObject$sub_refs {
	_jc_byte_array	*content;
	_jc_byte_array	*signature;
	struct _jc_java_lang_String$object	*thealgorithm;
};

// Reference instance fields (object)
struct _jc_java_security_SignedObject$refs {
    _jc_java_security_SignedObject$sub_refs	java_security_SignedObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_SignedObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_SignedObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_SignedObject$sub_nonrefs	java_security_SignedObject;
};

// Object instance structure
struct _jc_java_security_SignedObject$object {
	_jc_java_security_SignedObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_SignedObject$vtype	*vtype;
	_jc_java_security_SignedObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_SignedObject$vtype _jc_java_security_SignedObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_SignedObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_SignedObject$class_object;

#endif	/* _JC_java_security_SignedObject_H_ */

==> jc-1.4.6.tar.gz: java/security/SignedObject.h <==
// public final class java.security.SignedObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1d6c09729ddd8b58 java_security_SignedObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_SignedObject_H_
#define _JC_java_security_SignedObject_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_io_Serializable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_Signature$object;

// Typedefs
typedef struct _jc_java_security_SignedObject$sub_refs	_jc_java_security_SignedObject$sub_refs;
typedef struct _jc_java_security_SignedObject$sub_nonrefs	_jc_java_security_SignedObject$sub_nonrefs;
typedef struct _jc_java_security_SignedObject$refs	_jc_java_security_SignedObject$refs;
typedef struct _jc_java_security_SignedObject$nonrefs	_jc_java_security_SignedObject$nonrefs;
typedef struct _jc_java_security_SignedObject$object	_jc_java_security_SignedObject$object;

typedef struct _jc_java_security_SignedObject$fields_struct	_jc_java_security_SignedObject$fields_struct;
typedef const struct _jc_java_security_SignedObject$vmethods	_jc_java_security_SignedObject$vmethods;
typedef const struct _jc_java_security_SignedObject$vtable	_jc_java_security_SignedObject$vtable;
typedef const struct _jc_java_security_SignedObject$vtype	_jc_java_security_SignedObject$vtype;

// Class fields structure
struct _jc_java_security_SignedObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_SignedObject$fields_struct _jc_java_security_SignedObject$class_fields;

// Constructors
extern void _jc_java_security_SignedObject$method$_init$21c93dd2028dcec7(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_security_Signature$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_security_SignedObject$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_java_security_SignedObject$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_security_SignedObject$method$getObject$3a2eec332ceac060(_jc_env *, struct _jc_java_security_SignedObject$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_java_security_SignedObject$method$getSignature$40b505c8be88925d(_jc_env *, struct _jc_java_security_SignedObject$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_SignedObject$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_SignedObject$method$verify$36c10db3883f887f(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_object *, struct _jc_java_security_Signature$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_SignedObject$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_java_security_SignedObject$method_info$getObject$3a2eec332ceac060;
extern _jc_method _jc_java_security_SignedObject$method_info$getSignature$40b505c8be88925d;
extern _jc_method _jc_java_security_SignedObject$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_java_security_SignedObject$method_info$verify$36c10db3883f887f;

// Virtual methods structure
struct _jc_java_security_SignedObject$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_java_security_SignedObject$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getObject$3a2eec332ceac060)(_jc_env *, struct _jc_java_security_SignedObject$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getSignature$40b505c8be88925d)(_jc_env *, struct _jc_java_security_SignedObject$object *) _JC_JCNI_ATTR;
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*verify$36c10db3883f887f)(_jc_env *, struct _jc_java_security_SignedObject$object *, struct _jc_object *, struct _jc_java_security_Signature$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_SignedObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_SignedObject$vmethods	java_security_SignedObject;
};

// Vtype
struct _jc_java_security_SignedObject$vtype {
	_jc_type			type;
	_jc_java_security_SignedObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_SignedObject$sub_refs {
	_jc_byte_array	*content;
	_jc_byte_array	*signature;
	struct _jc_java_lang_String$object	*thealgorithm;
};

// Reference instance fields (object)
struct _jc_java_security_SignedObject$refs {
    _jc_java_security_SignedObject$sub_refs	java_security_SignedObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_SignedObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_SignedObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_SignedObject$sub_nonrefs	java_security_SignedObject;
};

// Object instance structure
struct _jc_java_security_SignedObject$object {
	_jc_java_security_SignedObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_SignedObject$vtype	*vtype;
	_jc_java_security_SignedObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_SignedObject$vtype _jc_java_security_SignedObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_SignedObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_SignedObject$class_object;

#endif	/* _JC_java_security_SignedObject_H_ */
